summaryrefslogtreecommitdiff
path: root/js/tt-rss.js
diff options
context:
space:
mode:
Diffstat (limited to 'js/tt-rss.js')
-rw-r--r--js/tt-rss.js13
1 files changed, 7 insertions, 6 deletions
diff --git a/js/tt-rss.js b/js/tt-rss.js
index 764667a0d..4a7f2e643 100644
--- a/js/tt-rss.js
+++ b/js/tt-rss.js
@@ -1,6 +1,6 @@
'use strict'
/* global require, App, $H */
/* exported Plugins */
const Plugins = {};
@@ -51,6 +51,7 @@ require(["dojo/_base/kernel",
"fox/FeedTree",
"fox/Toolbar",
"fox/SingleUseDialog",
+ "fox/form/ValidationMultiSelect",
"fox/form/ValidationTextArea",
"fox/form/Select",
"fox/form/ComboButton",
@@ -70,13 +71,13 @@ require(["dojo/_base/kernel",
/* exported hash_get */
function hash_get(key) {
- const kv = window.location.hash.substring(1).toQueryParams();
- return kv[key];
+ const obj = dojo.queryToObject(window.location.hash.substring(1));
+ return obj[key];
}
/* exported hash_set */
function hash_set(key, value) {
- const kv = window.location.hash.substring(1).toQueryParams();
- kv[key] = value;
- window.location.hash = $H(kv).toQueryString();
+ const obj = dojo.queryToObject(window.location.hash.substring(1));
+ obj[key] = value;
+ window.location.hash = dojo.objectToQuery(obj);
}
@@ -1,6 +1,6 @@
'use strict'
-/* global require, App, $H */
+/* global require, App, dojo */
/* exported Plugins */
const Plugins = {};